==> huaweicloudsdkiam-3.0.46-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/update_login_protect_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class UpdateLoginProtectResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'login_protect': 'UpdateLoginProtectRespon'
    }

    attribute_map = {
        'login_protect': 'login_protect'
    }

    def __init__(self, login_protect=None):
        """UpdateLoginProtectResponse - a model defined in huaweicloud sdk"""
        
        super(UpdateLoginProtectResponse, self).__init__()

        self._login_protect = None
        self.discriminator = None

        if login_protect is not None:
            self.login_protect = login_protect

    @property
    def login_protect(self):
        """Gets the login_protect of this UpdateLoginProtectResponse.


        :return: The login_protect of this UpdateLoginProtectResponse.
        :rtype: UpdateLoginProtectRespon
        """
        return self._login_protect

    @login_protect.setter
    def login_protect(self, login_protect):
        """Sets the login_protect of this UpdateLoginProtectResponse.


        :param login_protect: The login_protect of this UpdateLoginProtectResponse.
        :type: UpdateLoginProtectRespon
        """
        self._login_protect = login_protect

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateLoginProtectResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/update_login_protect_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class UpdateLoginProtectResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'login_protect': 'UpdateLoginProtectRespon'
    }

    attribute_map = {
        'login_protect': 'login_protect'
    }

    def __init__(self, login_protect=None):
        """UpdateLoginProtectResponse - a model defined in huaweicloud sdk"""
        
        super(UpdateLoginProtectResponse, self).__init__()

        self._login_protect = None
        self.discriminator = None

        if login_protect is not None:
            self.login_protect = login_protect

    @property
    def login_protect(self):
        """Gets the login_protect of this UpdateLoginProtectResponse.


        :return: The login_protect of this UpdateLoginProtectResponse.
        :rtype: UpdateLoginProtectRespon
        """
        return self._login_protect

    @login_protect.setter
    def login_protect(self, login_protect):
        """Sets the login_protect of this UpdateLoginProtectResponse.


        :param login_protect: The login_protect of this UpdateLoginProtectResponse.
        :type: UpdateLoginProtectRespon
        """
        self._login_protect = login_protect

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateLoginProtectResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
